nbxmpp.client_nb

Package nbxmpp :: Module client_nb |
[hide private]
[frames] | no frames]

# Module client_nb

source code

Client class establishs connection to XMPP Server and handles authentication

Classes | [hide private]
| NonBlockingClient Client class is XMPP connection mountpoint. Objects for authentication, network communication, roster, xml parsing ... are plugged to client object. Client implements the abstract behavior - mostly negotioation and callbacks handling, whereas underlying modules take care of feature-specific logic

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.client_nb')`
| __package__ = ``'``nbxmpp``'``

Imports: socket, transports_nb, dispatcher_nb, auth_nb, roster_nb, protocol, bosh, NS_TLS, logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.client_nb')

  ### __package__ Value:
      'nbxmpp'